@@ -29,9 +29,6 @@
 // KF
 #include <KAboutData>
 #include <KCrash>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 #include <KLocalizedString>
 // Qt
 #include <QApplication>
@@ -50,18 +47,8 @@ int main(int argc, char *argv[])
 {
     global_debug = 0;
 
-    // Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication app(argc, argv);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("kfourinline"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("kfourinlinerc"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("kfourinlineui.rc"));
-    migrate.migrate();
-#endif
     KLocalizedString::setApplicationDomain("kfourinline");
     KAboutData aboutData(QStringLiteral("kfourinline"),
                          i18n("KFourInLine"),
@@ -74,12 +61,15 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(i18n("Eugene Trounev"), i18n("Graphics"), QStringLiteral("eugene.trounev@gmail.com"));
     aboutData.addAuthor(i18n("Benjamin Meyer"), i18n("Code Improvements"));
     aboutData.setHomepage(QStringLiteral("https://apps.kde.org/kfourinline"));
-    QCommandLineParser parser;
+
     KAboutData::setApplicationData(aboutData);
+
     KCrash::initialize();
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("d") << QStringLiteral("debug"), i18n("Enter debug level"), QStringLiteral("level")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("skipintro"), i18n("Skip intro animation")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("demo"), i18n("Run game in demo (autoplay) mode")));
+
+    QCommandLineParser parser;
+    parser.addOption(QCommandLineOption({QStringLiteral("d"), QStringLiteral("debug")}, i18n("Enter debug level"), QStringLiteral("level")));
+    parser.addOption(QCommandLineOption({QStringLiteral("skipintro")}, i18n("Skip intro animation")));
+    parser.addOption(QCommandLineOption({QStringLiteral("demo")}, i18n("Run game in demo (autoplay) mode")));
 
     aboutData.setupCommandLine(&parser);
     parser.process(app);
